@@ -9,6 +9,7 @@ from abc import ABCMeta
 import httpx
 
 from livechat.utils.helpers import prepare_payload
+from livechat.utils.httpx_logger import HttpxLogger
 
 
 # pylint: disable=R0903
@@ -67,10 +68,16 @@ class CustomerWebInterface(metaclass=ABCMeta):
     ''' Main class containing API methods. '''
     def __init__(self, access_token: str, version: str, base_url: str,
                  http2: bool) -> CustomerWebInterface:
+        logger = HttpxLogger()
         self.api_url = f'https://{base_url}/v{version}/customer/action'
         if all([access_token, isinstance(access_token, str)]):
             self.session = httpx.Client(
-                http2=http2, headers={'Authorization': access_token})
+                http2=http2,
+                headers={'Authorization': access_token},
+                event_hooks={
+                    'request': [logger.log_request],
+                    'response': [logger.log_response]
+                })
         else:
             raise ValueError(
                 'Incorrect or missing `access_token` argument (should be of type str.)'
