@@ -9,6 +9,7 @@ from abc import ABCMeta
 import httpx
 
 from livechat.utils.helpers import prepare_payload
+from livechat.utils.httpx_logger import HttpxLogger
 
 
 class ReportsApi:
@@ -48,9 +49,14 @@ class ReportsApiInterface(metaclass=ABCMeta):
     ''' Interface class. '''
     def __init__(self, token: str, version: str, base_url: str,
                  http2: bool) -> ReportsApiInterface:
+        logger = HttpxLogger()
         self.api_url = f'https://{base_url}/v{version}/reports'
         self.session = httpx.Client(http2=http2,
-                                    headers={'Authorization': token})
+                                    headers={'Authorization': token},
+                                    event_hooks={
+                                        'request': [logger.log_request],
+                                        'response': [logger.log_response]
+                                    })
 
     def modify_header(self, header: dict) -> None:
         ''' Modifies provided header in session object.
